#################################################################################
# Created       : Martin Foster
# Modified      : 01/20/2000
#################################################################################
#
# Param - Modules part of Webchat designed to handle parameters diffrently
# Copyright (C) 2000  Martin Foster
#
# This program is free software; you can redistribute it and/or
# modify it under the terms of the GNU General Public License
# as published by the Free Software Foundation; either version 2
# of the License, or (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
#
# Author of this script can be contacted at the following:
#       E-Mail  : mfoster@redwhite.com
#       Address : Suite 209 - 355 5th Ave NE
#                 Calgary, Alberta
#                 T2R 0K9
#
#################################################################################
package Webchat::Param;

use strict;							# Strict variable enforcement
use Webchat::Login;						# Login procedures


#################################################################################
# Data Members
#################################################################################

#################################################################################
# Sub-Routines
#################################################################################

#####################
# GetParam
#
# Due to the annoyance of having to retrieve parameters from the $cgi->param
# command, I have opted to move them directly into a hash.  Passable to functions
# with little or no trouble and generally avoiding having the same value 
# re-applied to the parameter, causing problems for changes and easier calling
# via a hash.

sub GetParam
{
	#####################
	# Data members	
	my $cgi  = shift;					# Handle to CGI
	my $hash = shift;					# Reference to hash

	my @names;						# Array of named parameters reveived
	my $param;						# Specific parameter


	#####################
	# Program area

	@names = $cgi->param();					# Get list of all parameters received	
	
	# Cycle though parameter list
	while ($param = shift(@names))
	{
		$hash->{$param} = $cgi->param($param);		# Create hash with parameters
		$cgi->delete($param);				# Delete parameter list as one goes
	}
}


#####################
# Embed Information
#
# Will embed username and password for next pass

sub Embed                                                       # Database handle, CGI, Parameters
{
	#####################
	# Data members
	my $Database = shift;					# Database handle
	my $Statement;						# SQL Statement

	my $cgi = shift;					# CGI Handle
	my $param = shift;					# Parameter reference
	my $choice = shift;					# Choice of the matter

	my $crypt;						# Crypted password


	#####################
	# Data members

	# Unmange for use
	$param->{'USER'}   = Webchat::Login::Unmangle($param->{'USER'});

	# Prepare and execute
	$Statement = $Database->prepare("SELECT PuppeteerPassword FROM Puppeteer WHERE PuppeteerLogin=?");
	$Statement->execute($param->{'USER'});

	# Retreive and finish
	$crypt = $Statement->fetchrow();
	$Statement->finish();

	# Remangle in order to use
	$param->{'USER'} = Webchat::Login::Remangle($param->{'USER'});
	$param->{'ROOM'} = Webchat::Login::Remangle($param->{'ROOM'});
	$param->{'CHAR'} = Webchat::Login::Remangle($param->{'CHAR'});
	$param->{'NUM'}  = Webchat::Login::Remangle($param->{'NUM'});

	# If embed
	if ($choice == 0)
	{
		# Embed crypt and user
 		print "\t", $cgi->hidden('USER', $param->{'USER'}), "\n";
		print "\t", $cgi->hidden('CRYPT', $crypt), "\n";

		# Verify then encrypt
		if ( defined($param->{'ROOM'}) )
		{ print "\t", $cgi->hidden('ROOM', $param->{'ROOM'}), "\n"; }
		if ( defined($param->{'CHAR'}) )
		{ print "\t", $cgi->hidden('CHAR', $param->{'CHAR'}), "\n"; }
		if ( defined($param->{'NUM'}) )
		{ print "\t", $cgi->hidden('NUM', $param->{'NUM'}), "\n"; }
	}

	# Inline embeding
	elsif ($choice == 1)
	{
		# Assign default values for user and crypt
		my $string = "?USER=$param->{'USER'}&CRYPT=$crypt";

		# Verify then encrypt
		if ( defined($param->{'ROOM'}) )
		{ $string = "$string&ROOM=$param->{'ROOM'}"; }
		if ( defined($param->{'CHAR'}) )
		{ $string = "$string&CHAR=$param->{'CHAR'}"; }
		if ( defined($param->{'NUM'}) )
		{ $string = "$string&NUM=$param->{'NUM'}"; }

		# Return inline string
		return $string;
        }
}

# Alias for Normal
sub EmbedNormal
{ Embed(shift, shift, shift, 0); }

# Alias for Inline
sub EmbedInline
{ return Embed(shift, shift, shift, 1); }

1;								# Return true
